<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage News Vibe Pro
 * @since News Vibe Pro 1.0.0
 * @return array An array of default values
 */

function news_vibe_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$news_vibe_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#e5383e',
		'colorscheme'					=> 'default',
		'theme_color'					=> 'lite-version',
		'header_overlay_color'			=> '#000',
		'header_overlay'				=> 5,
		'home_layout'					=> 'default-design',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		'bg_image'						=> '',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'nav_search_enable'				=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		'read_more_text'           		=> esc_html__( 'Read More', 'news-vibe-pro' ),
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'news-vibe-pro' ), '[the-year]', '[site-link]' ) . esc_html__( 'All Rights Reserved | ', 'news-vibe-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'news-vibe-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'breakingnews,main_content,related_post',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'news-vibe-pro' ),
		'hide_category'					=> false,
		'hide_author'					=> false,
		'hide_date'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// Topbar
		'topbar_address'				=> esc_html__('Kathmandu, Nepal', 'news-vibe-pro' ),
		'topbar_email'					=> esc_html__('info@magazinebook.gmail.com', 'news-vibe-pro' ),
		'topbar_section_enable'			=> false,
		'secondary_menu_enable'			=> false,
		'social_menu_enable'			=> false,

		// Breaking News
		'breakingnews_section_enable'		=> true,
		'breakingnews_slider_auto_play'		=> false,
		'breakingnews_content_type'			=> 'post',
		'breakingnews_top'					=> false,
		'breakingnews_count'				=> 3,
		'breakingnews_title'				=> esc_html__( 'Breaking News', 'news-vibe-pro' ),

		'main_content_section_enable'		=> true,

		// Featured post
		'featured_post_section_enable' => true,
		'featured_post_content_type'	=> 'post',
		'featured_post_count'			=> 2,

		// Latest post
		'latest_post_title'				=> esc_html__( 'Latest News', 'news-vibe-pro' ),
		'latest_post_section_enable' => true,
		'latest_post_content_type'	=> 'post',
		'latest_post_count'			=> 3,

		// Popular
		'popular_section_enable'		=> true,
		'popular_title'					=> esc_html__( 'Most Popular', 'news-vibe-pro' ),
		'popular_count'					=> 3,
		'popular_content_type'			=> 'post',
		
		// Most viewed
		'most_viewed_section_enable'		=> true,
		'most_viewed_title'					=> esc_html__( 'Most Viewed', 'news-vibe-pro' ),
		'most_viewed_count'					=> 6,
		'most_viewed_content_type'			=> 'post',

		// Slider
		'slider_title'					=> esc_html__( 'SLIDER POSTS', 'news-vibe-pro' ),
		'slider_section_enable'			=> true,
		'slider_auto_play'				=> false,
		'slider_content_type'			=> 'post',
		'relatedpost_content_type'		=> 'post',
		'slider_count'					=> 3,
		'relatedpost_count'				=> 4,

		// related_post
		'related_post_section_enable'	=> true,
		'related_post_content_type'		=> 'post',
		'related_post_column'			=> 'col-4',
		'related_post_count'			=> 4,
		'related_post_title'			=> esc_html__( 'RECENTLY VIEWED', 'news-vibe-pro' ),

		//media posts
		'media_post_section_enable'		=> true,
		'media_post_title'				=> esc_html__( 'MEDIA POSTS', 'news-vibe-pro' ),
		'media_video_post_title'		=> esc_html__( 'How to learn any new programming language quickly', 'news-vibe-pro' ),
		'media_post_count'				=> 4,
		'video_post_count'				=> 1,
		'media_post_content_type'		=>'post',
		'media_video_post_content_type' => 'post',

		// Random post
		'random_post_section_enable'	=> true,
		'random_post_title'				=> esc_html__( 'Random Posts', 'news-vibe-pro' ),
		'random_post_count'				=> 3,
		'random_post_content_type'		=> 'post',

		//multi post 
		'multi_post_section_enable'		=> true,
		'multi_post_col1_title'			=> esc_html__( 'World News', 'news-vibe-pro' ),
		'multi_post_col1_count'			=> 5,
		'multi_post_col1_content_type'	=> 'post',
		'multi_post_col2_title'			=> esc_html__( 'Sport News', 'news-vibe-pro' ),
		'multi_post_col2_count'			=> 5,
		'multi_post_col2_content_type'	=> 'post',

	);

	$output = apply_filters( 'news_vibe_pro_default_theme_options', $news_vibe_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}