<?php
/**
* Media Posts Section options
*
* @package Theme Palace
* @subpackage News Vibe Pro
* @since News Vibe Pro 1.0.0
*/

// Add Media Post section
$wp_customize->add_section( 'news_vibe_pro_media_post_section', array(
	'title'             => esc_html__( 'Media Post Section','news-vibe-pro' ),
	'description'       => esc_html__( 'Media Post Section options.', 'news-vibe-pro' ),
	'panel'             => 'news_vibe_pro_front_page_panel',
	) );

// Media Post content enable control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[media_post_section_enable]', array(
	'default'			=> 	$options['media_post_section_enable'],
	'sanitize_callback' => 'news_vibe_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new News_Vibe_Pro_Switch_Control( $wp_customize, 'news_vibe_pro_theme_options[media_post_section_enable]', array(
	'label'             => esc_html__( 'Media Post Section Enable', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_media_post_section',
	'on_off_label' 		=> news_vibe_pro_switch_options(),
	) ) );

// Media Post btn title setting and control
$wp_customize->add_setting( 'news_vibe_pro_theme_options[media_post_title]', array(
	'default'			=> 	$options['media_post_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'news_vibe_pro_theme_options[media_post_title]', array(
	'label'           	=> esc_html__( 'Title', 'news-vibe-pro' ),
	'section'        	=> 'news_vibe_pro_media_post_section',
	'active_callback' 	=> 'news_vibe_pro_is_media_post_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'news_vibe_pro_theme_options[media_post_title]', array(
		'selector'            => '#inner-content-wrapper div#main-posts-wrapper div#media-posts h2.section-title',
		'settings'            => 'news_vibe_pro_theme_options[media_post_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'news_vibe_pro_media_post_title_partial',
		) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[video_post_count]', array(
	'default'          	=> $options['video_post_count'],
	'sanitize_callback' => 'news_vibe_pro_sanitize_number_range',
	'validate_callback' => 'news_vibe_pro_validate_video_post_count',
	) );

$wp_customize->add_control( 'news_vibe_pro_theme_options[video_post_count]', array(
	'label'             => esc_html__( 'Number of Video Posts', 'news-vibe-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 5. Please input the valid number and save. Then refresh the page to see the change.', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_media_post_section',
	'active_callback'   => 'news_vibe_pro_is_media_post_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 5,
		'style' => 'width: 100px;'
		),
	) );


// Media Post content type control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[media_video_post_content_type]', array(
	'default'          	=> $options['media_video_post_content_type'],
	'sanitize_callback' => 'news_vibe_pro_sanitize_select',
	) );

$wp_customize->add_control( 'news_vibe_pro_theme_options[media_video_post_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_media_post_section',
	'type'				=> 'select',
	'active_callback' 	=> 'news_vibe_pro_is_media_post_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'news-vibe-pro' ),
		'post' 		=> esc_html__( 'Post', 'news-vibe-pro' ),
		'category' 	=> esc_html__( 'Category', 'news-vibe-pro' ),
		),
	) );


for ( $i = 1; $i <= $options['video_post_count']; $i++ ) :

// media_post pages drop down chooser control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[media_video_post_content_page_'. $i .']', array(
	'sanitize_callback' => 'news_vibe_pro_sanitize_page',
	) );

$wp_customize->add_control( new News_Vibe_Pro_Dropdown_Chooser( $wp_customize, 'news_vibe_pro_theme_options[media_video_post_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'news-vibe-pro' ), $i ),
	'section'           => 'news_vibe_pro_media_post_section',
	'choices'			=> news_vibe_pro_page_choices(),
	'active_callback'	=> 'news_vibe_pro_is_video_post_section_content_page_enable',
	) ) );

// media_post posts drop down chooser control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[media_video_post_content_post_' . $i .']', array(
	'sanitize_callback' => 'news_vibe_pro_sanitize_page',
	) );

$wp_customize->add_control( new News_Vibe_Pro_Dropdown_Chooser( $wp_customize, 'news_vibe_pro_theme_options[media_video_post_content_post_' . $i .']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'news-vibe-pro' ), $i ),
	'section'           => 'news_vibe_pro_media_post_section',
	'choices'			=> news_vibe_pro_post_choices(),
	'active_callback'	=> 'news_vibe_pro_is_video_post_section_content_post_enable',
	) ) );

// media_post position setting and control
$wp_customize->add_setting( 'news_vibe_pro_theme_options[media_video_post_link_' .$i . ']', array(
	'sanitize_callback' => 'esc_url_raw',
	) );

$wp_customize->add_control( 'news_vibe_pro_theme_options[media_video_post_link_' .$i . ']', array(
	'label'           	=> sprintf( esc_html__( 'Video Link %d', 'news-vibe-pro' ), $i ),
	'section'        	=> 'news_vibe_pro_media_post_section',
	'active_callback' 	=> 'news_vibe_pro_is_media_post_section_enable',
	'type'				=> 'url',
	) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'news_vibe_pro_theme_options[media_video_post_content_category]', array(
	'sanitize_callback' => 'news_vibe_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new News_Vibe_Pro_Dropdown_Taxonomies_Control( $wp_customize,'news_vibe_pro_theme_options[media_video_post_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'news-vibe-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_media_post_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'news_vibe_pro_is_video_post_section_content_category_enable'
	) ) );



// media_post hr setting and control
$wp_customize->add_setting( 'news_vibe_pro_theme_options[media_post_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
	) );

$wp_customize->add_control( new News_Vibe_Pro_Customize_Horizontal_Line( $wp_customize, 'news_vibe_pro_theme_options[media_post_hr]',
	array(
		'section'         => 'news_vibe_pro_media_post_section',
		'active_callback' => 'news_vibe_pro_is_media_post_section_enable',
		'type'			  => 'hr'
		) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[media_post_count]', array(
	'default'          	=> $options['media_post_count'],
	'sanitize_callback' => 'news_vibe_pro_sanitize_number_range',
	'validate_callback' => 'news_vibe_pro_validate_media_post_count',
	) );

$wp_customize->add_control( 'news_vibe_pro_theme_options[media_post_count]', array(
	'label'             => esc_html__( 'Number of Media Posts', 'news-vibe-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_media_post_section',
	'active_callback'   => 'news_vibe_pro_is_media_post_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
	) );

// Media Post content type control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[media_post_content_type]', array(
	'default'          	=> $options['media_post_content_type'],
	'sanitize_callback' => 'news_vibe_pro_sanitize_select',
	) );

$wp_customize->add_control( 'news_vibe_pro_theme_options[media_post_content_type]', array(
	'label'             => esc_html__( 'Media Post Content Type', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_media_post_section',
	'type'				=> 'select',
	'active_callback' 	=> 'news_vibe_pro_is_media_post_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'news-vibe-pro' ),
		'post' 		=> esc_html__( 'Post', 'news-vibe-pro' ),
		'category'	=> esc_html__( 'Category', 'news-vibe-pro'),
		),
	) );

for ( $i = 1; $i <= $options['media_post_count']; $i++ ) :

// media_post pages drop down chooser control and setting
	$wp_customize->add_setting( 'news_vibe_pro_theme_options[media_post_content_page_' . $i . ']', array(
		'sanitize_callback' => 'news_vibe_pro_sanitize_page',
		) );

$wp_customize->add_control( new News_Vibe_Pro_Dropdown_Chooser( $wp_customize, 'news_vibe_pro_theme_options[media_post_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'news-vibe-pro' ), $i ),
	'section'           => 'news_vibe_pro_media_post_section',
	'choices'			=> news_vibe_pro_page_choices(),
	'active_callback'	=> 'news_vibe_pro_is_media_post_section_content_page_enable',
	) ) );

// media_post posts drop down chooser control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[media_post_content_post_' . $i . ']', array(
	'sanitize_callback' => 'news_vibe_pro_sanitize_page',
	) );

$wp_customize->add_control( new News_Vibe_Pro_Dropdown_Chooser( $wp_customize, 'news_vibe_pro_theme_options[media_post_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'news-vibe-pro' ), $i ),
	'section'           => 'news_vibe_pro_media_post_section',
	'choices'			=> news_vibe_pro_post_choices(),
	'active_callback'	=> 'news_vibe_pro_is_media_post_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'news_vibe_pro_theme_options[media_post_content_category]', array(
	'sanitize_callback' => 'news_vibe_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new News_Vibe_Pro_Dropdown_Taxonomies_Control( $wp_customize,'news_vibe_pro_theme_options[media_post_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'news-vibe-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_media_post_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'news_vibe_pro_is_media_post_section_content_category_enable'
	) ) );

