<?php
/**
* Multi Post Section options
*
* @package Theme Palace
* @subpackage News Vibe Pro
* @since News Vibe Pro 1.0.0
*/

// Add Multi Post section
$wp_customize->add_section( 'news_vibe_pro_multi_post_section', array(
	'title'             => esc_html__( 'Multi Post','news-vibe-pro' ),
	'description'       => esc_html__( 'Multi Post Section options.', 'news-vibe-pro' ),
	'panel'             => 'news_vibe_pro_front_page_panel',
	) );

// Multi Post content enable control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[multi_post_section_enable]', array(
	'default'			=> 	$options['multi_post_section_enable'],
	'sanitize_callback' => 'news_vibe_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new News_Vibe_Pro_Switch_Control( $wp_customize, 'news_vibe_pro_theme_options[multi_post_section_enable]', array(
	'label'             => esc_html__( 'Multi Post Section Enable', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_multi_post_section',
	'on_off_label' 		=> news_vibe_pro_switch_options(),
	) ) );

// multi_post title setting and control
$wp_customize->add_setting( 'news_vibe_pro_theme_options[multi_post_col1_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['multi_post_col1_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'news_vibe_pro_theme_options[multi_post_col1_title]', array(
	'label'           	=> esc_html__( 'Column 1 Title', 'news-vibe-pro' ),
	'section'        	=> 'news_vibe_pro_multi_post_section',
	'active_callback' 	=> 'news_vibe_pro_is_multi_post_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'news_vibe_pro_theme_options[multi_post_col1_title]', array(
		'selector'            => '#multiple-posts #col-1 h2',
		'settings'            => 'news_vibe_pro_theme_options[multi_post_col1_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'news_vibe_pro_multi_post_col1_title_partial',
		) );
}

// latest post number control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[multi_post_col1_count]', array(
	'default'          	=> $options['multi_post_col1_count'],
	'sanitize_callback' => 'news_vibe_pro_sanitize_number_range',
	'validate_callback' => 'news_vibe_pro_validate_multi_post_col1_count',
	) );

$wp_customize->add_control( 'news_vibe_pro_theme_options[multi_post_col1_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'news-vibe-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_multi_post_section',
	'active_callback'   => 'news_vibe_pro_is_multi_post_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
	) );

// Multi Post content type control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[multi_post_col1_content_type]', array(
	'default'          	=> $options['multi_post_col1_content_type'],
	'sanitize_callback' => 'news_vibe_pro_sanitize_select',
	) );

$wp_customize->add_control( 'news_vibe_pro_theme_options[multi_post_col1_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_multi_post_section',
	'type'				=> 'select',
	'active_callback' 	=> 'news_vibe_pro_is_multi_post_section_enable',
	'choices'			=> array( 
		'post' 		=> esc_html__( 'Post', 'news-vibe-pro' ),
		'page' 		=> esc_html__( 'Page', 'news-vibe-pro' ),
		'category' 	=> esc_html__( 'Category', 'news-vibe-pro' ),
		),
	) );

for ( $i = 1; $i <= $options['multi_post_col1_count']; $i++ ) :
// multi_post pages drop down chooser control and setting
	$wp_customize->add_setting( 'news_vibe_pro_theme_options[multi_post_col1_content_page_' . $i . ']', array(
		'sanitize_callback' => 'news_vibe_pro_sanitize_page',
		) );

$wp_customize->add_control( new News_Vibe_Pro_Dropdown_Chooser( $wp_customize, 'news_vibe_pro_theme_options[multi_post_col1_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'news-vibe-pro' ), $i ),
	'section'           => 'news_vibe_pro_multi_post_section',
	'choices'			=> news_vibe_pro_page_choices(),
	'active_callback'	=> 'news_vibe_pro_is_multi_post_col1_section_content_page_enable',
	) ) );

// multi_post posts drop down chooser control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[multi_post_col1_content_post_' . $i . ']', array(
	'sanitize_callback' => 'news_vibe_pro_sanitize_page',
	) );

$wp_customize->add_control( new News_Vibe_Pro_Dropdown_Chooser( $wp_customize, 'news_vibe_pro_theme_options[multi_post_col1_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'news-vibe-pro' ), $i ),
	'section'           => 'news_vibe_pro_multi_post_section',
	'choices'			=> news_vibe_pro_post_choices(),
	'active_callback'	=> 'news_vibe_pro_is_multi_post_col1_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'news_vibe_pro_theme_options[multi_post_col1_content_category]', array(
	'sanitize_callback' => 'news_vibe_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new News_Vibe_Pro_Dropdown_Taxonomies_Control( $wp_customize,'news_vibe_pro_theme_options[multi_post_col1_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'news-vibe-pro' ),
	'description'      	=> esc_html__( 'Note: Multi selected no of posts will be shown from selected category', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_multi_post_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'news_vibe_pro_is_multi_post_col1_section_content_category_enable'
	) ) );


    
// multi_post hr setting and control
$wp_customize->add_setting( 'news_vibe_pro_theme_options[multi_post_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
	) );

$wp_customize->add_control( new News_Vibe_Pro_Customize_Horizontal_Line( $wp_customize, 'news_vibe_pro_theme_options[multi_post_hr]',
	array(
		'section'         => 'news_vibe_pro_multi_post_section',
		'active_callback' => 'news_vibe_pro_is_multi_post_section_enable',
        'type'			  => 'hr'
    )));
/**
* Multi Post column 2 Section options
*
* @package Theme Palace
* @subpackage News Vibe Pro
* @since News Vibe Pro 1.0.0
*/

// multi_post title setting and control
$wp_customize->add_setting( 'news_vibe_pro_theme_options[multi_post_col2_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['multi_post_col2_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'news_vibe_pro_theme_options[multi_post_col2_title]', array(
	'label'           	=> esc_html__( 'Column 2 Title', 'news-vibe-pro' ),
	'section'        	=> 'news_vibe_pro_multi_post_section',
	'active_callback' 	=> 'news_vibe_pro_is_multi_post_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'news_vibe_pro_theme_options[multi_post_col2_title]', array(
		'selector'            => '#multiple-posts div#col-2 h2',
		'settings'            => 'news_vibe_pro_theme_options[multi_post_col2_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'news_vibe_pro_multi_post_col2_title_partial',
		) );
}

// latest post number control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[multi_post_col2_count]', array(
	'default'          	=> $options['multi_post_col2_count'],
	'sanitize_callback' => 'news_vibe_pro_sanitize_number_range',
	'validate_callback' => 'news_vibe_pro_validate_multi_post_col2_count',
	) );

$wp_customize->add_control( 'news_vibe_pro_theme_options[multi_post_col2_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'news-vibe-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_multi_post_section',
	'active_callback'   => 'news_vibe_pro_is_multi_post_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
	) );

// Multi Post content type control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[multi_post_col2_content_type]', array(
	'default'          	=> $options['multi_post_col2_content_type'],
	'sanitize_callback' => 'news_vibe_pro_sanitize_select',
	) );

$wp_customize->add_control( 'news_vibe_pro_theme_options[multi_post_col2_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_multi_post_section',
	'type'				=> 'select',
	'active_callback' 	=> 'news_vibe_pro_is_multi_post_section_enable',
	'choices'			=> array( 
		'post' 		=> esc_html__( 'Post', 'news-vibe-pro' ),
		'page' 		=> esc_html__( 'Page', 'news-vibe-pro' ),
		'category' 	=> esc_html__( 'Category', 'news-vibe-pro' ),
		),
	) );

for ( $i = 1; $i <= $options['multi_post_col2_count']; $i++ ) :
// multi_post pages drop down chooser control and setting
	$wp_customize->add_setting( 'news_vibe_pro_theme_options[multi_post_col2_content_page_' . $i . ']', array(
		'sanitize_callback' => 'news_vibe_pro_sanitize_page',
		) );

$wp_customize->add_control( new News_Vibe_Pro_Dropdown_Chooser( $wp_customize, 'news_vibe_pro_theme_options[multi_post_col2_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'news-vibe-pro' ), $i ),
	'section'           => 'news_vibe_pro_multi_post_section',
	'choices'			=> news_vibe_pro_page_choices(),
	'active_callback'	=> 'news_vibe_pro_is_multi_post_col2_section_content_page_enable',
	) ) );

// multi_post posts drop down chooser control and setting
$wp_customize->add_setting( 'news_vibe_pro_theme_options[multi_post_col2_content_post_' . $i . ']', array(
	'sanitize_callback' => 'news_vibe_pro_sanitize_page',
	) );

$wp_customize->add_control( new News_Vibe_Pro_Dropdown_Chooser( $wp_customize, 'news_vibe_pro_theme_options[multi_post_col2_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'news-vibe-pro' ), $i ),
	'section'           => 'news_vibe_pro_multi_post_section',
	'choices'			=> news_vibe_pro_post_choices(),
	'active_callback'	=> 'news_vibe_pro_is_multi_post_col2_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'news_vibe_pro_theme_options[multi_post_col2_content_category]', array(
	'sanitize_callback' => 'news_vibe_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new News_Vibe_Pro_Dropdown_Taxonomies_Control( $wp_customize,'news_vibe_pro_theme_options[multi_post_col2_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'news-vibe-pro' ),
	'description'      	=> esc_html__( 'Note: Multi selected no of posts will be shown from selected category', 'news-vibe-pro' ),
	'section'           => 'news_vibe_pro_multi_post_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'news_vibe_pro_is_multi_post_col2_section_content_category_enable'
	) ) );