<?php
/**
* Random Post section
*
* This is the template for the content of random_post section
*
* @package Theme Palace
* @subpackage News Vibe Pro
* @since News Vibe Pro 1.0.0
*/

$options = news_vibe_pro_get_theme_options();

if( $options['random_post_section_enable'] !== false ):

// Content type.
$random_post_content_type  = $options['random_post_content_type'];
$random_post_count = ! empty( $options['random_post_count'] ) ? $options['random_post_count'] : 3;
$content_details = array();

switch ( $random_post_content_type ) {
    case 'page':
        $page_ids = array();
        for ( $i = 1; $i <= $random_post_count; $i++ ) {
            if ( ! empty( $options['random_post_content_page_' . $i] ) )
                $page_ids[] = $options['random_post_content_page_' . $i];
        }
        $args = array(
            'post_type'         => 'page',
            'post__in'          => ( array ) $page_ids,
            'posts_per_page'    => absint( $random_post_count ),
            'orderby'           => 'post__in',
            );
        break;

    case 'post':
        $post_ids = array();
        for ( $i = 1; $i <= $random_post_count; $i++ ) {
            if ( ! empty( $options['random_post_content_post_' . $i] ) )
                $post_ids[] = $options['random_post_content_post_' . $i];
        }
        $args = array(
            'post_type'         => 'post',
            'post__in'          => ( array ) $post_ids,
            'posts_per_page'    => absint( $random_post_count ),
            'orderby'           => 'post__in',
            'ignore_sticky_posts'   => true,
            );
        break;

    case 'category':
        $cat_ids = ! empty( $options['random_post_content_category'] ) ? $options['random_post_content_category'] : '';
        $args = array(
            'post_type'         => 'post',
            'posts_per_page'    => absint( $random_post_count ),
            'cat'               => absint( $cat_ids ),
            'ignore_sticky_posts'   => true,
            );
        break;

    default:
    break;
}
// Run The Loop.
$query = new WP_Query( $args );
if ( $query->have_posts() ) :
    while ( $query->have_posts() ) : $query->the_post();
        $page_post['id']        = get_the_id();
        $page_post['auth_id']   = get_the_author_meta('ID');
        $page_post['title']     = get_the_title();
        $page_post['content']   = get_the_content();
        $page_post['url']       = get_the_permalink();
        $page_post['excerpt']   = news_vibe_pro_trim_content( 25 );
        $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
        // Push to the main array.
        array_push( $content_details, $page_post );
    endwhile;
endif;
wp_reset_postdata();
?>

    <div id="random-posts" class="relative list-layout">
        <div class="section-header">
            <h2 class="section-title"><?php echo esc_html( $options['random_post_title'] ); ?></h2>
        </div><!-- .section-header -->

        <div class="section-content clear">
            <?php 
                foreach( $content_details as $key => $content ) :
                $full_width = (($key+1) % 3 == 1) ? 'full-width' : '';
                
                if($key != 0 && !empty($full_width) ) echo '<div class="separator-line clear"></div>';
                ?>
                <article class="has-post-thumbnail <?php echo $full_width; ?>">
                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image']); ?>');">
                        <a href="<?php echo esc_url($content['url'] ); ?>" class="post-thumbnail-link"></a>
                        <span class="min-read">
                            <?php echo news_vibe_pro_time_interval( $content['content'] ); esc_html_e(' min to read', 'news-vibe-pro'); ?>
                        </span>
                    </div><!-- .featured-image -->

                    <div class="entry-container">
                        <div class="entry-meta">
                            <span class="cat-links">
                                <?php the_category( '', '', $content['id'] ); ?>
                            </span><!-- .cat-links -->

                            
                            <?php if( !empty($full_width) )  news_vibe_pro_posted_on( $content['id'] ); ?>

                        </div><!-- .entry-meta -->

                        <header class="entry-header">
                            <h2 class="entry-title"><a href="<?php echo esc_url($content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                        </header>

                        <?php if( !empty($full_width) )  echo news_vibe_pro_author( $content['auth_id'] );?>

                    </div><!-- .entry-container -->
                </article>
            <?php endforeach ; ?>
        </div><!-- .section-content -->
    </div><!-- #random-posts -->

<?php endif; ?>

