<?php
/**
 * Slider Posts Widget
 *
 * @package Theme Palace
 * @subpackage News Vibe Pro
 * @since News Vibe Pro 1.0.0
 */

if ( ! class_exists( 'news_vibe_Slider_Post' ) ) :


    class News_Vibe_Slider_Post extends WP_Widget {
        /**
         * Sets up the widgets name etc
         */
        public function __construct() {
            $tp_widget_right_sidebar_slider_post = array(
                'classname'   => 'posts-slider',
                'description' => esc_html__( 'Retrive slider posts.', 'news-vibe-pro' ),
                );
            parent::__construct( 'news_vibe_pro_right_sidebar_slider_post', esc_html__( 'TP : Slider Posts', 'news-vibe-pro' ), $tp_widget_right_sidebar_slider_post );
        }

        /**
         * Outputs the content of the widget
         *
         * @param array $args
         * @param array $instance
         */
        public function widget( $args, $instance ) {
            // outputs the content of the widget
            if ( ! isset( $args['widget_id'] ) ) {
                $args['widget_id'] = $this->id;
            }

            $tp_title  = ( ! empty( $instance['title'] ) ) ? ( $instance['title'] ) : '';
            $tp_title  = apply_filters( 'widget_title', $tp_title, $instance, $this->id_base );
            $tp_number = isset( $instance['number'] ) ? absint( $instance['number'] ) : 3;
            $tp_category = isset( $instance['category'] ) ? absint( $instance['category'] ) : '';

           
            ?>
            <section id="slider-posts" class="widget widget_posts_slider">
                <div class="widget-header">
                <h2 class="widget-title"><?php echo esc_html( $tp_title ) ;?></h2>
                </div><!-- .widget-header -->

                <div class="posts-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": false, "draggable": true, "fade": false }'>
                <?php
                $slider_args = array(
                 'post_type'         => 'post',
                 'posts_per_page'    => absint( $tp_number ),
                 'order'             => 'DESC',
                 'cat'               => absint( $tp_category ),
                 );
                $wp_query = new WP_Query( $slider_args );
                if ( $wp_query->have_posts() ) : 
                while ( $wp_query->have_posts() ) : $wp_query->the_post();
                $image = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
                $id = get_the_id();
                $content = get_the_content($id);
                 ?>

                    <article style="background-image: url('<?php echo esc_url($image); ?>');">
                        <div class="entry-container">
                            <div class="entry-meta">
                                <span class="cat-links">
                                    <?php the_category(''); ?>
                                </span>

                                <?php news_vibe_pro_posted_on(); ?>
                            </div><!-- .entry-meta -->

                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
                            </header>

                            <span class="min-read"><?php echo news_vibe_pro_time_interval( $content ); echo esc_html__(' min to read', 'news-vibe-pro'); ?></span>
                            <?php echo news_vibe_pro_author( get_the_author_meta('ID') ); ?>
                            
                        </div><!-- .entry-container -->
                    </article>
                <?php endwhile; 
                wp_reset_postdata();
            endif;
                ?>

                </div><!-- .posts-slider -->
            </section>
            <?php
            
        }

        /**
         * Outputs the options form on admin
         *
         * @param array $instance The widget options
         */
        public function form( $instance ) {
            $tp_title      = isset( $instance['title'] ) ? ( $instance['title'] ) : esc_html__( 'Slider Posts', 'news-vibe-pro' );
            $tp_number     = isset( $instance['number'] ) ? absint( $instance['number'] ) : 3;
            $tp_category   = isset( $instance['category'] ) ? absint( $instance['category'] ) : '';
            ?>

            <p>
             <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'news-vibe-pro' ); ?></label>
             <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('title') ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $tp_title ); ?>" />
         </p>

         <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"><?php esc_html_e( 'Number of posts to show:', 'news-vibe-pro' ); ?></label>
            <input class="tiny-text" id="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number' ) ); ?>" type="number" step="1" min="1" max="7" value="<?php echo absint( $tp_number ); ?>" size="3" />
        </p>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'category' ) ); ?>"><?php esc_html_e( 'Select the category to show posts:', 'news-vibe-pro' ); ?></label>
            <select id="<?php echo esc_attr( $this->get_field_id('category') ); ?>" name="<?php echo $this->get_field_name('category'); ?>" class="widefat" style="width:100%;">

                <?php 
                $categories = news_vibe_pro_category_choices();
                foreach($categories as $category => $value) { ?>
                <option value="<?php echo absint( $category ); ?>" <?php selected( $tp_category, $category ); ?>><?php echo esc_html( $value ); ?></option>
                <?php } ?>      
            </select>
        </p>

        <?php
    }

        /**
        * Processing widget options on save
        *
        * @param array $new_instance The new options
        * @param array $old_instance The previous options
        */
        public function update( $new_instance, $old_instance ) {
            // processes widget options to be saved
            $instance           = $old_instance;
            $instance['title']  = sanitize_text_field( $new_instance['title'] );
            $instance['number'] = (int) $new_instance['number'];
            $instance['category'] = news_vibe_pro_sanitize_single_category( $new_instance['category'] );

            return $instance;
        }
    }
    endif;
